AndroidKeySettings

Struct AndroidKeySettings 

#[non_exhaustive]
pub struct AndroidKeySettings { pub allow_all_package_names: bool, pub allowed_package_names: Vec<String>, pub support_non_google_app_store_distribution: bool, /* private fields */ }
Settings specific to keys that can be used by Android apps.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
allow_all_package_names: bool

Optional. If set to true, allowed_package_names are not enforced.

allowed_package_names: Vec<String>

Optional. Android package names of apps allowed to use the key. Example: ‘com.companyname.appname’ Each key supports a maximum of 250 package names. To use a key on more apps, set allow_all_package_names to true. When this is set, you are responsible for validating the package name by checking the token_properties.android_package_name field in each assessment response against your list of allowed package names.

support_non_google_app_store_distribution: bool

Optional. Set to true for keys that are used in an Android application that is available for download in app stores in addition to the Google Play Store.

Implementations

Source

impl AndroidKeySettings

pub fn new() -> Self

Creates a new default instance.

pub fn set_allow_all_package_names<T: Into<bool>>(self, v: T) -> Self

Sets the value of allow_all_package_names.

Example
let x = AndroidKeySettings::new().set_allow_all_package_names(true);
pub fn set_allowed_package_names<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<String>,

Sets the value of allowed_package_names.

Example
let x = AndroidKeySettings::new().set_allowed_package_names(["a", "b", "c"]);
pub fn set_support_non_google_app_store_distribution<T: Into<bool>>( self, v: T, ) -> Self

Sets the value of support_non_google_app_store_distribution.

Example
let x = AndroidKeySettings::new().set_support_non_google_app_store_distribution(true);